.. module:: pymaker

===
API
===

Welcome to the API of Pymaker!

----------
Exceptions
----------

.. autoexception:: RecursiveDefinitionError

----------------
Public Functions
----------------

.. autodecorator:: command

.. autofunction:: declare_argument

.. autofunction:: r

.. autofunction:: main

-----------------
Private Functions
-----------------

.. autofunction:: build_direc

.. autofunction:: call_command

.. autofunction:: make_help_message
